@@ -10,7 +10,10 @@ from swh.model.model import Origin, OriginVisit, OriginVisitStatus
 from swh.storage.interface import ListOrder, StorageInterface
 
 
-def iter_origins(storage: StorageInterface, limit: int = 10000,) -> Iterator[Origin]:
+def iter_origins(
+    storage: StorageInterface,
+    limit: int = 10000,
+) -> Iterator[Origin]:
     """Iterates over origins in the storage.
 
     Args:
@@ -78,18 +81,14 @@ def origin_get_latest_visit_status(
 def iter_origin_visits(
     storage: StorageInterface, origin: str, order: ListOrder = ListOrder.ASC
 ) -> Iterator[OriginVisit]:
-    """Iter over origin visits from an origin
-
-    """
+    """Iter over origin visits from an origin"""
     yield from stream_results(storage.origin_visit_get, origin, order=order)
 
 
 def iter_origin_visit_statuses(
     storage: StorageInterface, origin: str, visit: int, order: ListOrder = ListOrder.ASC
 ) -> Iterator[OriginVisitStatus]:
-    """Iter over origin visit status from an origin visit
-
-    """
+    """Iter over origin visit status from an origin visit"""
     yield from stream_results(
         storage.origin_visit_status_get, origin, visit, order=order
     )
