@@ -1318,7 +1318,12 @@ class CassandraStorage:
         next_page_token = None
         date_from = None
         if page_token is not None:
-            date_from = datetime.datetime.fromisoformat(page_token)
+            try:
+                date_from = datetime.datetime.fromisoformat(page_token)
+            except ValueError:
+                raise StorageArgumentException(
+                    "Invalid page_token argument to origin_visit_status_get."
+                ) from None
 
         # Take one more visit status so we can reuse it as the next page token if any
         rows = self._cql_runner.origin_visit_status_get_range(
