@@ -21,6 +21,7 @@ from swh.model.model import (
     ObjectType,
     Origin,
     OriginVisit,
+    OriginVisitStatus,
     Person,
     RawExtrinsicMetadata,
     Release,
@@ -185,12 +186,39 @@ class StorageData:
             ],
         ),
     )
+
+    directory6 = Directory(
+        id=hash_to_bytes("afa0105cfcaa14fdbacee344e96659170bb1bda5"),
+        entries=tuple(
+            [
+                DirectoryEntry(
+                    name=b"foo",
+                    type="file",
+                    target=b"\x00" * 20,
+                    perms=from_disk.DentryPerms.content,
+                ),
+                DirectoryEntry(
+                    name=b"bar",
+                    type="dir",
+                    target=b"\x01" * 20,
+                    perms=from_disk.DentryPerms.directory,
+                ),
+            ],
+        ),
+        raw_manifest=(
+            b"tree 61\x00"
+            b"100644 foo\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"  # noqa
+            b"40000 bar\x00\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01\x01"  # noqa
+        ),
+    )
+
     directories: Tuple[Directory, ...] = (
         directory2,
         directory,
         directory3,
         directory4,
         directory5,
+        directory6,
     )
 
     revision = Revision(
@@ -552,6 +580,36 @@ class StorageData:
         origin_visit3,
     )
 
+    origin_visit_status = OriginVisitStatus(
+        origin=origin.url,
+        visit=1,
+        date=date_visit1,
+        type=type_visit1,
+        status="created",
+        snapshot=None,
+    )
+    origin_visit2_status = OriginVisitStatus(
+        origin=origin.url,
+        visit=2,
+        date=date_visit2,
+        type=type_visit1,
+        status="created",
+        snapshot=None,
+    )
+    origin_visit3_status = OriginVisitStatus(
+        origin=origin2.url,
+        visit=1,
+        date=date_visit1,
+        type=type_visit2,
+        status="created",
+        snapshot=None,
+    )
+    origin_visit_statuses: Tuple[OriginVisitStatus, ...] = (
+        origin_visit_status,
+        origin_visit2_status,
+        origin_visit3_status,
+    )
+
     release = Release(
         id=hash_to_bytes("f7f222093a18ec60d781070abec4a630c850b837"),
         name=b"v0.0.1",
